/*********************************************************************
 *  SPDX-License-Identifier: MIT									 *
 *  Copyright (C) 2008-2024 by Helge Kortendieck  alan@kasmithee.de  *
 *                                                                   *
 *  This file is part of siimvi.                                     *
 *********************************************************************/
#ifndef _INFO_H_
#define _INFO_H_

#include <QApplication>
#include <QByteArray>
#include <QEvent>
#include <QFileInfo>
#include <QFont>
#include <QKeyEvent>
#include <QLabel>
#include <QMouseEvent>
#include <QPoint>
#include <QSettings>
#include <QSize>
#include <QString>
#include <QWidget>
//#include <QX11Info>

#include "ui_info.h"

#include "exiftool.h"
#include "structs.h"

/*
#include <X11/X.h>
#include <X11/Xlib.h>
#include <X11/Xatom.h>
*/

#include <iostream>
using namespace std;
//using namespace mncanon;


class InfoW : public QWidget
{
	Q_OBJECT

public:
	InfoW(QWidget* parent = 0);  //, Qt::WindowFlags fl = Qt::Dialog
		~InfoW();


protected slots:
    /*$PROTECTED_SLOTS$*/
	void closeEvent(QCloseEvent*);
	void hideEvent(QHideEvent*);
	void keyPressEvent(QKeyEvent*);
	void mousePressEvent(QMouseEvent*);


private:
	bool bEt;				// info widget created
	bool bOk;				// conversion of string to number was successful (or not)
	bool bSetFont;			// set different font size

	double dD;                // dummy double
	double dD2;               // dummy double

	int iD;
	int iD2;
	int iD3;
	int iD4;
	int iD5;
	int iExiv2;				// exiv2 version, used to see if available
	int iFontSize;			// font size to set
	int iHeight;			// dialog height
	int iWidth;				// dialog width

  // image infos received from siv.cpp
	int iImOrigX;             // original image width
	int iImOrigY;             // original image height
	int iImCurX;              // current image width
	int iImCurY;              // current image height
	int iRotate;              // rotation: 0=none, 1=90° right, 2=180°, 3=90°left

	Ui::Info uii;             // info widget

	ExifInf eiD;              // exif info struct (dummy) entity
	ExifInf eiE;              // exif info struct entity

	QByteArray qba;

	QChar qchr;

	QPoint posI;

	QSize sizeI;

	QString sD;               // dummy string
	QString sD2;              // dummy string
	QString sD3;              // dummy string
	QString sDDimOrig;        // original image size
	QString sDDimShow;        // image size image is currently shown and orientation
	QString sDDepth;          // image colour depth
	QString sFocalMin;
	QString sFocalMax;
	QString sImCur;           // image to show, full path and name
	QString sLensType;        // lens type
	QString sMake;            // make (manufacturer) of the camera, needed to read specific Maker Note tags
	QString sTitle;           // error widget title
	QString sText;            // error text

	QStringList slD;          // dummy QStringList

	QWidget wInfo;            // info widget

	Exiftool *et;			// exiftool object to collect exif information

private slots:

	void convDouble();						// found '/',  assume x/y: turn this calculation into double and back in qstring sD to show in widget

	void dlgShow();							// show info dialog
	void dlgToFrt();						// bring dialog back to front
	void dlgClose();						// close dialog

	void iwUpd( const QString& sD, int iD, int iD2, int iD3, int iD4, int iD5 );   // get info what image info to show
	void iwClear();							// clear image info widget entries
	void iwGet();							// get image information
	void iwExifEtCreate();					// create infoExif object
	void iwExifGet();						// get exif info of image
	void iwExifGot( const ExifInf& eiD );	// received exif info from exiftool
	void iwExifPop();						// populate info widget with exif information, then show
	void iwExifErr();						// error while getting exif tags for info widget - aborting

	void setRead();							// read settings
	void setWrite();						// write settings

	signals:
		void sigGetExif( const QString& );		// request exif info for this picture (QString = full abs path n name of current image)
		void sigInfErr( const QString&, const QString& );	// error while getting exif information
		void sigInfHidden();					// image info widget hidden
};

#endif
