/*********************************************************************
 *  SPDX-License-Identifier: MIT									 *
 *  Copyright (C) 2007-2024 by Helge Kortendieck  alan@kasmithee.de  *
 *                                                                   *
 *  This file is part of siimvi.                                     *
 *********************************************************************/
#include <iostream>
using namespace std;

#include <QApplication>
#include <QStringList>

#include "siv.h"

int main(int argc, char *argv[])
{
  QApplication app(argc, argv);
  QStringList slArgs = QApplication::arguments();  // get command line args
  int iArgs = slArgs.count();
  bool bH = false;
  bool bV = false;
  QString sD = "";

  if (iArgs > 1) {
    for (int i = 1; i < iArgs; ++i) {
      sD = slArgs.at(i);
      if (sD == "-v" or sD == "--version") {
        bV = true;
      } else if (sD == "-h" or sD == "--help") {
        bH = true;
      }
    }
    if (bV or bH) {
      cout << "\n###  siimvi - a simple image viewer\n"
              "###  Based on Qt6\n"
              "###  Using exiv2 to get Exif tag information if available\n"
	          "###  Version 2.0.0\n"
	          "###  Copyright (C) 2008-2024 by Helge Kortendieck, alan@kasmithee.de\n"
              "###  Released under the MIT license\n" << endl;
    }
    if (bH) {
      cout << "###  Invoke siimvi with at least one image to show.\n"
              "###  If there are other image files in the directory of the first,\n"
              "###  you can then cycle between them with the mouse wheel.\n"
              "###  Or give a number of image files, space separated, on the\n"
              "###  command line and you can cycle between these.\n"
              "###  The only command line options qimview understands are -v or\n"
              "###  --version to show version only or -h or --help to show this\n"
              "###  short help message. But all output only to stdout, the console.\n" << endl;
    }
  } else {
      cout << "\n###  siimvi - no image to show !\n"
              "###  You must invoke siimvi with at least one image to show.\n"
              "###  If there are other image files in the directory of the first,\n"
              "###  you can then cycle between them with the mouse wheel.\n"
              "###  Or give a number of image files, space separated, on the\n"
              "###  command line and you can cycle between these.\n"
              "###  Aborting...\n" << endl;
  }

  if (!bV and !bH) {
    Siv siv;
    siv.show();
    return app.exec();
  }
}

